##  Creating To-Dos
### Creating Action Items and Asking Questions
Every user can create action item and ask question to-dos. The process of creating these two types of to-dos is similar. Follow these steps to create a to-do item:
  1. Open the fact sheet in which the to-do item needs to be created and select the To-Dos tab.
  2. In the To-Dos tab, select Add Action Item or Ask Question, as needed. This action opens a modal where you can define your task or state your question.


**Tip**
You can also access the Add Action Item or Ask Question options from the More actions menu (represented by 3 dots) at the top right of the fact sheet. This provides quick and easy access without the need to navigate to the To-Dos tab.
![Creating Action Items and Ask Question To-Dos](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9869263bab5745fd9f3d5147f138dbb7_LowRes.png)
Creating Action Item and Ask Question To-Dos
  1. In the modal, provide a title, add a description, and due date. If the responsible person is known, assign them to the task.
![Defining a To-Do item](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27486edb7a441014ba70cffd82b9a7bd_LowRes.png)
Defining a To-Do item
  2. Click Add. This action saves the new to-do item in the To-Dos tab of the fact sheet.


### Creating Approval To-Dos
Only admins can create approval to-dos. Approval to-dos are created through the automation feature in the administration area. When the automation is triggered, defined approval to-dos are automatically created and assigned to relevant users, making it an efficient means of governance. To learn how to create an approval to-do, see [Creating Approval To-Dos](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275dbdde7a4410148637f298598afe49__creating_approval_to-dos).
